import React, { useEffect, useState } from 'react';
import { Modal, Form, Select, Button, Card, Typography, message } from 'antd';
import { CloseOutlined, PlusOutlined, EditOutlined, CaretRightFilled } from '@ant-design/icons';
import VideoSelectModal from '../videoSelectModal';
import EditTitleCoverModal from '../editTitleCoverModal';
import { VideoItem } from '../types'; // Import from common types
import { GzhPlanType } from '../../hooks/useGzhPlanList';
import { useAccountOptions } from '../../hooks/useAccountOptions';

const { Option } = Select;
const { Text } = Typography;

interface AddPunlishPlanModalProps {
	visible: boolean;
	onCancel: () => void;
	onOk: (values: GzhPlanType) => void; // Pass form values on OK
	actionType: 'add' | 'edit';
	editPlanData?: GzhPlanType;
	isSubmiting?: boolean;
}

const AddPunlishPlanModal: React.FC<AddPunlishPlanModalProps> = ({ visible, isSubmiting, onCancel, onOk, actionType, editPlanData }) => {
	const [form] = Form.useForm();
	const [selectedVideos, setSelectedVideos] = useState<VideoItem[]>([]);
	const [isVideoSelectVisible, setIsVideoSelectVisible] = useState(false);
	const [playingVideo, setPlayingVideo] = useState<VideoItem | null>(null); // State for video player modal
	const [editingVideo, setEditingVideo] = useState<VideoItem | null>(null); // State for editing modal
	const { accountOptions } = useAccountOptions();

	useEffect(() => {
		if (actionType === 'edit') {
			form.setFieldsValue(editPlanData);
			setSelectedVideos(editPlanData?.videoList || []);
		}
	}, [actionType, editPlanData]);

	const handleOk = () => {
		form
			.validateFields()
			.then((values) => {
				// Ensure at least one video is selected before submitting
				if (selectedVideos.length === 0) {
					message.error('请至少选择一个视频'); // Use Antd message
					return;
				}
				onOk({ ...values, scene: 0, videoList: selectedVideos });
			})
			.catch((info) => {
				console.log('Validate Failed:', info);
			});
	};

	const removeVideo = (idToRemove: number) => {
		setSelectedVideos(currentVideos => currentVideos.filter(video => video.videoId !== idToRemove));
	};

	const openVideoSelector = () => {
		setIsVideoSelectVisible(true);
	};

	const handleVideoSelectionOk = (newlySelectedVideos: VideoItem[]) => {
		// Merge existing custom data with newly selected videos
		const currentCustomData = new Map<number, Partial<VideoItem>>();
		selectedVideos.forEach(v => {
			if (v.cover) {
				currentCustomData.set(v.videoId, { title: v.title, cover: v.cover });
			}
		});

		const mergedVideos = newlySelectedVideos.map(newVideo => {
			const customData = currentCustomData.get(newVideo.videoId);
			return { ...newVideo, ...customData };
		});

		setSelectedVideos(mergedVideos);
		setIsVideoSelectVisible(false);
	};

	const handleVideoSelectionCancel = () => {
		setIsVideoSelectVisible(false);
	};

	const playVideo = (video: VideoItem) => {
		setPlayingVideo(video);
	};

	const closeVideoPlayer = () => {
		setPlayingVideo(null);
	};

	const openEditModal = (video: VideoItem) => {
		setEditingVideo(video);
	};

	const handleEditOk = (updatedData: Partial<VideoItem>) => {
		console.log('updatedData', updatedData);
		setSelectedVideos(currentVideos =>
			currentVideos.map(v =>
				v.videoId === editingVideo?.videoId ? { ...v, ...updatedData } : v
			)
		);
		setEditingVideo(null); // Close modal
	};

	const handleEditCancel = () => {
		setEditingVideo(null);
	};

	return (
		<>
			<Modal
				title="创建发布计划"
				open={visible}
				destroyOnClose
				onCancel={onCancel}
				width={900} // Adjust width as needed
				footer={[
					<Button key="back" onClick={onCancel}>
						取消
					</Button>,
					<Button key="submit" type="primary" loading={isSubmiting} onClick={handleOk}>
						确定
					</Button>,
				]}
				zIndex={10}
			>
				<Form form={form} layout="vertical">
					<Form.Item
						name="id"
						label="计划ID"
						hidden
					>
					</Form.Item>
					<Form.Item
						name="publishStage"
						label="发布方"
						labelCol={{ span: 4 }}
						labelAlign='left'
						layout="horizontal"
						rules={[{ required: true, message: '请选择发布方' }]}
					>
						<Select placeholder="选择发布方" allowClear className='!w-50'>
							<Option value={0}>平台发布</Option>
							<Option value={1}>用户发布</Option>
						</Select>
					</Form.Item>
					<Form.Item
						name="accountId"
						label="公众号名称"
						labelCol={{ span: 4 }}
						labelAlign='left'
						layout="horizontal"
						rules={[{ required: true, message: '请选择公众号' }]}
					>
						<Select
							placeholder="选择公众号"
							allowClear
							className='!w-50'
							options={accountOptions.map(option => ({ label: option.name, value: option.id }))}>
						</Select>
					</Form.Item>
					<Form.Item
						name="scene"
						label="发布场景"
						layout="horizontal"
						labelCol={{ span: 4 }}
						labelAlign='left'
					>
						<Select
							placeholder="发布场景"
							className='!w-50'
							defaultValue={0}
							options={[{ label: '关注回复', value: 0 }]}>
						</Select>
					</Form.Item>

					<Form.Item label="发布内容" required>
						<div className="flex flex-wrap gap-4">
							{selectedVideos.map((video) => (
								<Card
									key={video.videoId}
									className="w-[240px] relative group"
								>
									<Button
										shape="circle"
										icon={<CloseOutlined />}
										className="!absolute top-1 right-1 z-10 bg-gray-400 bg-opacity-50 border-none text-white hidden group-hover:inline-flex justify-center items-center"
										size="small"
										onClick={() => removeVideo(video.videoId)}
									/>
									<div className="p-0">
										<Text type="secondary" className="text-xs">票圈 | 3亿人喜欢的视频平台</Text>
										<Text className="block mt-1 mb-2 leading-tight line-clamp-2" title={video.customTitle || video.title}>{video.customTitle || video.title}</Text>
									</div>
									<div
										className="relative h-[120px] bg-gray-200 cursor-pointer group/thumb"
										onClick={(e) => {
											e.stopPropagation(); // Prevent card selection if clicking thumbnail/play
											playVideo(video);
										}}
									>
										<img src={video.customCover || video.cover} referrerPolicy="no-referrer" className="w-full h-full object-cover" />
										<div className="absolute inset-0 flex justify-center items-center cursor-pointer">
											<CaretRightFilled className="!text-white text-4xl bg-black/20 rounded-full p-1 pl-2" />
										</div>
									</div>
									<div className="p-3">
										<Text type="secondary" className="text-xs">传播效率: {video.score?.toFixed(2)}</Text>
										<Button
											icon={<EditOutlined />}
											className="w-full mt-2"
											onClick={() => openEditModal(video)} // Open edit modal
										>
											编辑标题/封面
										</Button>
									</div>
								</Card>
							))}

							{/* Add Video Button - Conditionally Rendered */}
							{selectedVideos.length < 3 && (
								<div
									className="w-[240px] h-[316px] flex flex-col justify-center items-center bg-gray-100 border border-dashed border-gray-300 rounded cursor-pointer hover:border-blue-500 hover:text-blue-500"
									onClick={openVideoSelector} // Open the drawer on click
								>
									<PlusOutlined className="text-2xl mb-2" />
									<Typography.Text>添加视频</Typography.Text>
								</div>
							)}
						</div>
					</Form.Item>
				</Form>
			</Modal>

			{/* Video Selection Drawer */}
			<VideoSelectModal
				visible={isVideoSelectVisible}
				onClose={handleVideoSelectionCancel}
				onOk={handleVideoSelectionOk}
				initialSelectedIds={selectedVideos.map(v => v.videoId)} // Pass current selection IDs
			/>

			{/* Video Player Modal */}
			<Modal
				open={!!playingVideo}
				onCancel={closeVideoPlayer}
				title={playingVideo?.title}
				footer={null}
				destroyOnClose // Unmount video element when closed
				width={720} // Adjust as needed
				styles={{ body: { padding: 0, background: '#000' } }}
				zIndex={20}
			>
				{playingVideo && (
					<video
						controls
						autoPlay
						className="w-full h-auto max-h-[80vh] block"
						src={playingVideo.video}
					>
						Your browser does not support the video tag.
					</video>
				)}
			</Modal>

			{/* Edit Title/Cover Modal */}
			<EditTitleCoverModal
				visible={!!editingVideo}
				onCancel={handleEditCancel}
				onOk={handleEditOk}
				video={editingVideo}
			/>
		</>
	);
};

export default AddPunlishPlanModal;
